__author__ = 'vincent'

from django.db import models
from django.utils.translation import ugettext_lazy as _
from realestate.models import House, Group, HouseKind, SubGroup
from crm.models import Customer


class Buyer(models.Model):
    customer = models.OneToOneField(Customer, primary_key=True,
                                    verbose_name=_('customer'), on_delete=models.CASCADE)
    house = models.OneToOneField(House, blank=False, null=False, related_name="buyer_house",
                                 verbose_name=_('house'), on_delete=models.CASCADE)
    option = models.BooleanField(_('option'), default=False)
    option_from = models.DateField(_('option from'), null=True, blank=True)
    option_until = models.DateField(_('option until'), null=True, blank=True)
    signed_agreement = models.BooleanField(_('signed agreement'), default=False)
    signed_agreement_date = models.DateField(_('signed agreement date'), blank=True, null=True)
    notary = models.DateField(_('notary'), null=True, blank=True)
    finance_status = models.TextField(_('status finance'), blank=True)

    def __unicode__(self):
        return self.customer.__unicode__()

    class Meta:
        verbose_name = _('buyer')
        verbose_name_plural = _('buyers')
        ordering = ['house__number']


class Lead(models.Model):
    customer = models.OneToOneField(Customer, primary_key=True,
                                    verbose_name=_('customer'), on_delete=models.CASCADE)
    created = models.DateTimeField(_('created'), null=True, blank=True, auto_now_add=True)
    edited = models.DateTimeField(_('edited'), null=True, blank=True, auto_now=True)
    min_price = models.IntegerField(_('min price'), null=True, blank=True)
    max_price = models.IntegerField(_('max price'), null=True, blank=True)
    houses = models.ManyToManyField(House, blank=True, related_name="lead_houses",
                                    verbose_name=_('houses'))
    groups = models.ManyToManyField(Group, blank=True, related_name="lead_groups",
                                    verbose_name=_('projects'))
    subgroups = models.ManyToManyField(SubGroup, blank=True, related_name="lead_subgroups",
                                       verbose_name=_('woning types'))
    house_kinds = models.ManyToManyField(HouseKind, blank=True, related_name="lead_house_kinds",
                                         verbose_name=_('kinds of houses'))
    comment = models.TextField(_('comment'), blank=True)

    class Meta:
        verbose_name = _('lead')
        verbose_name_plural = _('leads')
        ordering = ['-edited']

    def __unicode__(self):
        return self.customer.__unicode__()